@@ -96,7 +96,7 @@ def request(kw, step):
     expected['status_code'] = expected.get('status_code', None)
     expected['text'] = expected.get('text', None)
     json_str = expected.get('json', '{}')
-    if json_str[0] == '[':
+    if json_str[0] == '[' and json_str[1] != ']':
         index = json_str.split(']')[0][1:]
         expected['json'] = json2dict(json_str[len(index) + 2:])
         expected['json_index'] = int(index)
